@@ -12,6 +12,7 @@ from collections import namedtuple
 from concurrent.futures import ProcessPoolExecutor
 
 import pypdfium2.raw as pdfium_c
+import pypdfium2.internal as pdfium_i
 from pypdfium2.version import (
     V_LIBPDFIUM,
     V_BUILDNAME,
@@ -21,7 +22,6 @@ from pypdfium2._helpers.misc import PdfiumError
 from pypdfium2._helpers.page import PdfPage
 from pypdfium2._helpers.pageobjects import PdfObject
 from pypdfium2._helpers.attachment import PdfAttachment
-import pypdfium2.internal as pdfium_i
 
 logger = logging.getLogger(__name__)
 
@@ -151,11 +151,6 @@ class PdfDocument (pdfium_i.AutoCloseable):
                 Custom form config interface to use (optional).
         """
         
-        # safety check for older binaries (could be removed at some point)
-        # https://github.com/bblanchon/pdfium-binaries/issues/105
-        if V_PDFIUM_IS_V8 and V_BUILDNAME == "pdfium-binaries" and int(V_LIBPDFIUM) <= 5677:
-            raise RuntimeError("V8 enabled pdfium-binaries builds <= 5677 crash on init_forms().")
-        
         formtype = self.get_formtype()
         if formtype == pdfium_c.FORMTYPE_NONE or self.formenv:
             return
@@ -167,6 +162,11 @@ class PdfDocument (pdfium_i.AutoCloseable):
             else:
                 config = pdfium_c.FPDF_FORMFILLINFO(version=2)
         
+        # safety check for older binaries to prevent a segfault (could be removed at some point)
+        # https://github.com/bblanchon/pdfium-binaries/issues/105
+        if V_PDFIUM_IS_V8 and int(V_LIBPDFIUM) <= 5677 and V_BUILDNAME == "pdfium-binaries":
+            raise RuntimeError("V8 enabled pdfium-binaries builds <= 5677 crash on init_forms().")
+        
         raw = pdfium_c.FPDFDOC_InitFormFillEnvironment(self, config)
         if not raw:
             raise PdfiumError(f"Initializing form env failed for document {self}.")
@@ -209,21 +209,7 @@ class PdfDocument (pdfium_i.AutoCloseable):
         return bool( pdfium_c.FPDFCatalog_IsTagged(self) )
     
     
-    def _save_to(self, buffer, version=None, flags=pdfium_c.FPDF_NO_INCREMENTAL):
-        
-        c_writer = pdfium_i.get_bufwriter(buffer)
-        saveargs = (self, c_writer, flags)
-        
-        if version is None:
-            ok = pdfium_c.FPDF_SaveAsCopy(*saveargs)
-        else:
-            ok = pdfium_c.FPDF_SaveWithVersion(*saveargs, version)
-        
-        if not ok:
-            raise PdfiumError("Failed to save document.")
-    
-    
-    def save(self, dest, *args, **kwargs):
+    def save(self, dest, version=None, flags=pdfium_c.FPDF_NO_INCREMENTAL):
         """
         Save the document at its current state.
         
@@ -236,13 +222,22 @@ class PdfDocument (pdfium_i.AutoCloseable):
             flags (int):
                 PDFium saving flags (defaults to :attr:`FPDF_NO_INCREMENTAL`).
         """
+        
         if isinstance(dest, (str, Path)):
-            with open(dest, "wb") as buf:
-                self._save_to(buf, *args, **kwargs)
+            buffer, need_close = open(dest, "wb"), True
         elif pdfium_i.is_buffer(dest, "w"):
-            self._save_to(dest, *args, **kwargs)
+            buffer, need_close = dest, False
         else:
             raise ValueError(f"Cannot save to '{dest}'")
+        
+        try:
+            saveargs = (self, pdfium_i.get_bufwriter(buffer), flags)
+            ok = pdfium_c.FPDF_SaveAsCopy(*saveargs) if version is None else pdfium_c.FPDF_SaveWithVersion(*saveargs, version)
+            if not ok:
+                raise PdfiumError("Failed to save document.")
+        finally:
+            if need_close:
+                buffer.close()
     
     
     def get_identifier(self, type=pdfium_c.FILEIDTYPE_PERMANENT):
@@ -401,7 +396,7 @@ class PdfDocument (pdfium_i.AutoCloseable):
             index = len(self)
         raw_page = pdfium_c.FPDFPage_New(self, index, width, height)
         page = PdfPage(raw_page, self, None)
-        # FIXME should we make the formenv distinction for new pages, too?
+        # not doing formenv calls for new pages as we don't see the point
         self._add_kid(page)
         return page
     
