@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: 2023 geisserml <geisserml@gmail.com>
 # SPDX-License-Identifier: Apache-2.0 OR BSD-3-Clause
 
-__all__ = ["PdfMatrix"]
+__all__ = ("PdfMatrix", )
 
 import math
 import ctypes
@@ -45,10 +45,10 @@ class PdfMatrix:
         return f"PdfMatrix{self.get()}"
     
     
-    def __eq__(self, matrix):
-        if type(self) is not type(matrix):
+    def __eq__(self, other):
+        if type(self) is not type(other):
             return False
-        return (self.get() == matrix.get())
+        return (self.get() == other.get())
     
     
     @property
