@@ -7,11 +7,11 @@ import math
 import ctypes
 import logging
 import pypdfium2.raw as pdfium_c
+import pypdfium2.internal as pdfium_i
 from pypdfium2._helpers.misc import PdfiumError
 from pypdfium2._helpers.bitmap import PdfBitmap
 from pypdfium2._helpers.textpage import PdfTextPage
 from pypdfium2._helpers.pageobjects import PdfObject
-import pypdfium2.internal as pdfium_i
 
 c_float = ctypes.c_float
 logger = logging.getLogger(__name__)
@@ -228,7 +228,9 @@ class PdfPage (pdfium_i.AutoCloseable):
         if pageobj.page is not self:
             raise ValueError("The page object you attempted to remove is not part of this page.")
         
-        pdfium_c.FPDFPage_RemoveObject(self, pageobj)
+        ok = pdfium_c.FPDFPage_RemoveObject(self, pageobj)
+        if not ok:
+            raise PdfiumError("Failed to remove pageobject.")
         pageobj.page = None
         pageobj._attach_finalizer()
     
@@ -281,12 +283,7 @@ class PdfPage (pdfium_i.AutoCloseable):
             if raw_obj is None:
                 raise PdfiumError("Failed to get page object.")
             
-            helper_obj = PdfObject(
-                raw = raw_obj,
-                page = self,
-                pdf = self.pdf,
-                level = level,
-            )
+            helper_obj = PdfObject(raw_obj, page=self, pdf=self.pdf, level=level)
             self._add_kid(helper_obj)
             if not filter or helper_obj.type in filter:
                 yield helper_obj
@@ -422,12 +419,7 @@ class PdfPage (pdfium_i.AutoCloseable):
         if (color_scheme is not None) and fill_to_stroke:
             flags |= pdfium_c.FPDF_CONVERT_FILL_TO_STROKE
         
-        bitmap = bitmap_maker(
-            width = width,
-            height = height,
-            format = cl_format,
-            rev_byteorder = rev_byteorder,
-        )
+        bitmap = bitmap_maker(width, height, format=cl_format, rev_byteorder=rev_byteorder)
         bitmap.fill_rect(0, 0, width, height, fill_color)
         
         render_args = (bitmap, self, -crop[0], -crop[3], src_width, src_height, pdfium_i.RotationToConst[rotation], flags)
